dloud_ads
=========

.. image:: https://img.shields.io/pypi/v/dloud_ads.svg
    :target: https://pypi.python.org/pypi/dloud_ads
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/dataloudlabs/dloud-ads.png
   :target: https://travis-ci.org/dataloudlabs/dloud-ads
   :alt: Latest Travis CI build status

Abstract Data Structures commonly used in CS scenarios. Implemented by Data Loud Labs!

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`dloud_ads` was written by `Pedro Sousa <pjgs.sousa@gmail.com>`_.
